//
//  DataObject.m
//
//  Created on 08.04.10.
//

#import "DataObject.h"
#import "CredentialsHelper.h"

@implementation DataObject

static NSDictionary* plistRoot;

+(void)checkLoadData
{
	if (!plistRoot)
	{
		NSString *plistFile = [[NSBundle mainBundle] pathForResource:@"services" ofType:@"plist"];
		plistRoot = [[NSDictionary dictionaryWithContentsOfFile:plistFile] retain];
	}
}

// Get list of services from config file
+(NSArray*)getServicesList
{
	[DataObject checkLoadData];
	return 	[plistRoot allKeys];
}

// Get list of methods for particular service from config
+(NSArray*)getMethodsListForService:(NSString*)aService
{
	[DataObject checkLoadData];
	NSDictionary *service = [plistRoot valueForKey:aService];
	service = [service valueForKey:@"Methods"];
	return [service allKeys];
}

// Get REST proxy method name from config
+(NSString*)getServiceName:(NSString*)aService
{
	[DataObject checkLoadData];
	NSDictionary *service = [plistRoot valueForKey:aService];
	return [service valueForKey:@"Name"];
}

+(NSString*)buldRequestURLByName:(NSString*)aServiceName andMethodName:(NSString*)aMethodName
{
	NSString *serviceURIName = [DataObject getServiceName:aServiceName];
	NSString *serviceHost = [CredentialsHelper getMainServiceURL];
	return [NSString stringWithFormat:@"%@/%@/%@", serviceHost, serviceURIName, aMethodName];
}

+(NSData*)buildHTTPRequestBodyByName:(NSString*)aServiceName andMethodName:(NSString*)aMethodName 
						andAuthToken:(NSString*)aToken
{
	[DataObject checkLoadData];
	NSDictionary *service = [plistRoot valueForKey:aServiceName];
	NSDictionary *methodsList = [service valueForKey:@"Methods"];
	NSString *requestTemplateResID = [methodsList valueForKey:aMethodName]; 
	NSString *xmlFileTemplatePath = [[NSBundle mainBundle] pathForResource:requestTemplateResID ofType:@"xml"];
	NSString *stringContent = [NSString stringWithFormat:[NSString stringWithContentsOfFile:xmlFileTemplatePath encoding:NSUTF8StringEncoding error: NULL], aToken];
	NSData *xmlData = [stringContent dataUsingEncoding:NSUTF8StringEncoding];
	return xmlData;
}

@end
